@@ -1,7 +1,9 @@
 package Sah::Schema::country::code::alpha3;
 
-our $DATE = '2018-04-08'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2019-11-29'; # DATE
+our $DIST = 'Sah-Schemas-Country'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 use Locale::Codes::Country_Codes ();
 
@@ -22,7 +24,7 @@ Code will be converted to lowercase.
 _
     match => '\A[a-z]{3}\z',
     in => $codes,
-    'x.perl.coerce_rules' => ['str_tolower'],
+    'x.perl.coerce_rules' => ['From_str::to_lower'],
 }, {}];
 
 1;
@@ -40,7 +42,7 @@ Sah::Schema::country::code::alpha3 - Country code (alpha-3)
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::country::code::alpha3 (from Perl distribution Sah-Schemas-Country), released on 2018-04-08.
+This document describes version 0.003 of Sah::Schema::country::code::alpha3 (from Perl distribution Sah-Schemas-Country), released on 2019-11-29.
 
 =head1 DESCRIPTION
 
@@ -76,7 +78,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
